@@ -66,6 +66,7 @@
 #endif
 
 #ifdef HAVE_LIBHILDON
+#include <hildon/hildon-helper.h>
 #else
 #include <hildon-widgets/hildon-finger.h>
 #endif 
@@ -310,20 +311,34 @@ hn_app_switcher_toggle_menu_button (HNAppSwitcher *app_switcher)
 	  l->data != app_switcher->priv->main_home_item)
       {
         GtkWidget *item;
-	      
-        if ((l->next)->data)
+	
+        if (l->next && (l->next)->data)
           item = GTK_WIDGET ((l->next)->data);        		
 	else
 	  item = app_switcher->priv->main_home_item;
 
+	if (GTK_IS_SEPARATOR_MENU_ITEM (item))
+        {		
+	  app_switcher->priv->active_menu_item = item;
+          continue;
+	}
+
 	app_switcher->priv->active_menu_item = item;
 	
         gtk_menu_shell_select_item (GTK_MENU_SHELL (app_switcher->priv->main_menu), item);	      
+	g_debug ("home %p item %p",app_switcher->priv->main_home_item,item);
+	break;
       }
       else 
-      if (l->data == app_switcher->priv->main_home_item)
+      if (l->data == app_switcher->priv->main_home_item &&
+	  children->next)
+      {	      
 	gtk_menu_shell_select_item (GTK_MENU_SHELL (app_switcher->priv->main_menu), 
 			            GTK_WIDGET (children->data));
+
+	app_switcher->priv->active_menu_item = GTK_WIDGET (children->data);
+	break;
+      }
    }	
 	 
    return;
@@ -975,10 +990,10 @@ menu_button_pressed_cb (GtkWidget      *widget,
 
   /*FIXME: We will have to rewrite this */
 /*  hd_wm_activate (HN_TN_DEACTIVATE_KEY_FOCUS);*/
-#ifndef HILDON_LIBS
+#ifndef HAVE_LIBHILDON
   if (event->button == APP_BUTTON_THUMBABLE || event->button == 2)
 #else
-  if (hildon_button_event_is_finger (event))
+  if (hildon_helper_event_button_is_finger (event))
 #endif
     priv->is_thumbable = TRUE;
   else 
@@ -1076,6 +1091,8 @@ hn_app_switcher_show_menu_cb (HDWM *hdwm, gpointer data)
 {
   HNAppSwitcher *app_switcher = HN_APP_SWITCHER (data);
 
+  app_switcher->priv->is_thumbable = TRUE;
+
   hn_app_switcher_toggle_menu_button (app_switcher);
 }
 
@@ -1241,7 +1258,7 @@ hn_app_switcher_build (HNAppSwitcher *app_switcher)
 		    (gpointer)app_switcher);
 
   g_signal_connect (app_switcher->hdwm,
-		    "long-press-key",
+		    "long-key-press",
 		    G_CALLBACK (hn_app_switcher_long_press_cb),
 		    (gpointer)app_switcher);
 
